# dido

**dido** is an API server and Web application for the **aeneas** forced aligner

* Version: 0.0.1
* Date: 2017-03-09
* Developed by: [ReadBeyond](http://www.readbeyond.it/)
* Lead Developer: [Alberto Pettarin](http://www.albertopettarin.it/)
* License: the GNU Affero General Public License Version 3 (AGPL v3)
* Contact: [dido@readbeyond.it](mailto:dido@readbeyond.it)


## Important Notice

This is work in progress.
Please do not use the code until it reaches v1.0.0.
